==> v1.0.18.tar.gz: ventoy/README.md <==
# Ventoy  [https://www.ventoy.net](https://www.ventoy.net)
Ventoy is an open source tool to create bootable USB drive for ISO files.   
With ventoy, you don't need to format the disk over and over, you just need to copy the iso file to the USB drive and boot it.   
You can copy many iso files at a time and ventoy will give you a boot menu to select them.  
Both Legacy BIOS and UEFI are supported in the same way. 420+ ISO files are tested.  
A "Ventoy Compatible" concept is introduced by ventoy, which can help to support any ISO file.  

See https://www.ventoy.net for detail.

# Features
* 100% open source
* Simple to use
* Fast (limited only by the speed of copying iso file)
* Directly boot from iso file, no extraction needed
* Legacy + UEFI supported in the same way
* UEFI Secure Boot supported (since 1.0.07+)
* Persistence supported (since 1.0.11+)
* MBR and GPT partition style supported (1.0.15+)
* WIM files boot supported (Legacy + UEFI) (1.0.12+)
* Auto installation supported (1.0.09+)
* ISO files larger than 4GB supported
* Native boot menu style for Legacy & UEFI
* Most type of OS supported, 420+ iso files tested
* Not only boot but also complete installation process
* ISO files can be listed in List mode/TreeView mode
* "Ventoy Compatible" concept
* Plugin Framework
* USB drive write-protected support
* USB normal use unaffected
* Data nondestructive during version upgrade
* No need to update Ventoy when a new distro is released

![avatar](https://www.ventoy.net/static/img/screen/screen_uefi.png)


# Installation Instructions
See [https://www.ventoy.net/en/doc_start.html](https://www.ventoy.net/en/doc_start.html) for detail

# Compile Instructions
Please refer to [BuildVentoyFromSource.txt](https://github.com/ventoy/Ventoy/blob/master/DOC/BuildVentoyFromSource.txt)

# Document
Title | Link
-|-
**Install & Update** | [https://www.ventoy.net/en/doc_start.html](https://www.ventoy.net/en/doc_start.html)
**Customize Theme** | [https://www.ventoy.net/en/plugin_theme.html](https://www.ventoy.net/en/plugin_theme.html)  
**Global Control** | [https://www.ventoy.net/en/plugin_control.html](https://www.ventoy.net/en/plugin_control.html)  
**Auto Installation** | [https://www.ventoy.net/en/plugin_autoinstall.html](https://www.ventoy.net/en/plugin_autoinstall.html)  
**Injection Plugin** | [https://www.ventoy.net/en/plugin_injection.html](https://www.ventoy.net/en/plugin_injection.html)  
**Persistence Support** | [https://www.ventoy.net/en/plugin_persistence.html](https://www.ventoy.net/en/plugin_persistence.html)  
**Boot WIM file** | [https://www.ventoy.net/en/plugin_wimboot.html](https://www.ventoy.net/en/plugin_wimboot.html)  
**Menu Class** | [https://www.ventoy.net/en/plugin_menuclass.html](https://www.ventoy.net/en/plugin_menuclass.html)  
**Menu Alias** | [https://www.ventoy.net/en/plugin_menualias.html](https://www.ventoy.net/en/plugin_menualias.html)  
**Menu Extension** | [https://www.ventoy.net/en/plugin_grubmenu.html](https://www.ventoy.net/en/plugin_grubmenu.html)  
**Memdisk Mode** | [https://www.ventoy.net/en/doc_memdisk.html](https://www.ventoy.net/en/doc_memdisk.html)  
**TreeView Mode** | [https://www.ventoy.net/en/doc_treeview.html](https://www.ventoy.net/en/doc_treeview.html)  
**Disk Layout MBR** | [https://www.ventoy.net/en/doc_disk_layout.html](https://www.ventoy.net/en/doc_disk_layout.html)  
**Disk Layout GPT** | [https://www.ventoy.net/en/doc_disk_layout_gpt.html](https://www.ventoy.net/en/doc_disk_layout_gpt.html)  


# FAQ
See [https://www.ventoy.net/en/faq.html](https://www.ventoy.net/en/faq.html) for detail


# Forum
[https://forums.ventoy.net](https://forums.ventoy.net)

==> v1.0.24.tar.gz: ventoy/README.md <==
<h1 align="center">
  <a href=https://www.ventoy.net/>Ventoy</a>
</h1>

<p align="center">
  <img src="https://img.shields.io/github/release/ventoy/Ventoy.svg?style=for-the-badge">
  <img src="https://img.shields.io/github/license/ventoy/Ventoy?style=for-the-badge">
  <img src="https://img.shields.io/github/stars/ventoy/Ventoy?style=for-the-badge">
  <img src="https://img.shields.io/github/downloads/ventoy/Ventoy/total.svg?style=for-the-badge">
</p>

<h4 align="left">
Ventoy is an open source tool to create bootable USB drive for ISO/WIM/IMG/VHD(x)/EFI files. <br/>
With ventoy, you don't need to format the disk over and over, you just need to copy the image files to the USB drive and boot it.   
You can copy many iso files at a time and ventoy will give you a boot menu to select them. <br/> 
Both Legacy BIOS and UEFI are supported in the same way.<br/>
Both MBR and GPT partition style are supported in the same way.<br/>
Most type of OS supported(Windows/WinPE/Linux/Unix/Vmware/Xen...) <br/>
550+ ISO files are tested. 90%+ distros in distrowatch.com supported. <br/>
</h4>

# Features
* 100% open source
* Simple to use
* Fast (limited only by the speed of copying iso file)
* Directly boot from ISO/WIM/IMG/VHD(x)/EFI file, no extraction needed
* Legacy + UEFI supported in the same way
* UEFI Secure Boot supported (since 1.0.07+)
* Persistence supported (since 1.0.11+)
* MBR and GPT partition style supported (1.0.15+)
* WIM files boot supported (Legacy + UEFI) (1.0.12+)
* IMG files boot supported (Legacy + UEFI) (1.0.19+)
* Auto installation supported (1.0.09+)
* File injection supported (1.0.16+)
* ISO files larger than 4GB supported
* Native boot menu style for Legacy & UEFI
* Most type of OS supported(Windows/WinPE/Linux/Unix/Vmware/Xen...), 550+ iso files tested
* Not only boot but also complete installation process
* ISO files can be listed in List mode/TreeView mode
* Linux vDisk boot supported (vdi/vhd/raw)
* "Ventoy Compatible" concept
* Plugin Framework
* Menu Alias/Menu Style/Customized Menu supported
* USB drive write-protected support
* USB normal use unaffected
* Data nondestructive during version upgrade
* No need to update Ventoy when a new distro is released

![avatar](https://www.ventoy.net/static/img/screen/screen_uefi.png)


# Installation Instructions
See [https://www.ventoy.net/en/doc_start.html](https://www.ventoy.net/en/doc_start.html) for detail

# Compile Instructions
Please refer to [BuildVentoyFromSource.txt](https://github.com/ventoy/Ventoy/blob/master/DOC/BuildVentoyFromSource.txt)

# Document
Title | Link
-|-
**Install & Update** | [https://www.ventoy.net/en/doc_start.html](https://www.ventoy.net/en/doc_start.html)
**Customize Theme** | [https://www.ventoy.net/en/plugin_theme.html](https://www.ventoy.net/en/plugin_theme.html)  
**Global Control** | [https://www.ventoy.net/en/plugin_control.html](https://www.ventoy.net/en/plugin_control.html)  
**Auto Installation** | [https://www.ventoy.net/en/plugin_autoinstall.html](https://www.ventoy.net/en/plugin_autoinstall.html)  
**Injection Plugin** | [https://www.ventoy.net/en/plugin_injection.html](https://www.ventoy.net/en/plugin_injection.html)  
**Persistence Support** | [https://www.ventoy.net/en/plugin_persistence.html](https://www.ventoy.net/en/plugin_persistence.html)  
**Boot WIM file** | [https://www.ventoy.net/en/plugin_wimboot.html](https://www.ventoy.net/en/plugin_wimboot.html)  
**Menu Class** | [https://www.ventoy.net/en/plugin_menuclass.html](https://www.ventoy.net/en/plugin_menuclass.html)  
**Menu Alias** | [https://www.ventoy.net/en/plugin_menualias.html](https://www.ventoy.net/en/plugin_menualias.html)  
**Menu Extension** | [https://www.ventoy.net/en/plugin_grubmenu.html](https://www.ventoy.net/en/plugin_grubmenu.html)  
**Memdisk Mode** | [https://www.ventoy.net/en/doc_memdisk.html](https://www.ventoy.net/en/doc_memdisk.html)  
**TreeView Mode** | [https://www.ventoy.net/en/doc_treeview.html](https://www.ventoy.net/en/doc_treeview.html)  
**Disk Layout MBR** | [https://www.ventoy.net/en/doc_disk_layout.html](https://www.ventoy.net/en/doc_disk_layout.html)  
**Disk Layout GPT** | [https://www.ventoy.net/en/doc_disk_layout_gpt.html](https://www.ventoy.net/en/doc_disk_layout_gpt.html)  


# FAQ
See [https://www.ventoy.net/en/faq.html](https://www.ventoy.net/en/faq.html) for detail


# Forum
[https://forums.ventoy.net](https://forums.ventoy.net)
